# Attribute Name  =	Value   #Comments
# _tom Setup Mode File - PCM

# Take care of the detector heater and DHE cooling parameters
VFanTempSensorSlct=1    # Set the temperature servo sensor to be the FPGA die temperature
VFanTempSetPoint=46     # Set the DHE internal temperature control at 46 Deg. measured on the FPGA die.
VFanServoEnable=0       # Disable the servo for now
VFanServoPwmValue=30    # VFan servo currently doesn't exist .. run the fan at 30% rate
VFanEnable=1            # Enable the DHE cooling fan power supply

VHtrTempSensorSlct=1    # Select temperature sensor number 1 for detector temperature control.
VHtrTempSetPoint=160    # Set the detector temperature to be 160 Kelvin
VHtrServoEnable=0       # Disable the heater servo - It currently doesn't exist
VHtrServoPwmValue=0     # Turn off the heater by dropping it's power level to 0% max
VHtrEnable=1            # Enable the detector heater power supply

PwrUpAfes=1             # Power on the supplies to the AFE cards after the primary supplies are settled

# Setup for using the test program (@ start vector 16) to generate ADC data
contRun=0
afeControlEnbl=1  # Allow interface control via gateway to AFE1
CDSPortEnbl=15    # Enable four channels on AFE1
CdsPortCfg=0      # Treat AFE1 and AFE2 as seperate devices
chanSrcSlct[]=0   # Disable all channels
chanSrcSlct[0]=1  # Map acquisition channel 1 to hardware channel 1
chanSrcSlct[1]=2  # Map acquisition channel 2 to hardware channel 2
chanSrcSlct[2]=3  # Map acquisition channel 3 to hardware channel 3
chanSrcSlct[3]=4  # Map acquisition channel 4 to hardware channel 4

# Setup debug channels for scope
DbgSigSlct=2      # Select PSM group
DbgTrigGrpSlct=2  # Trigger from V80 Sync signal
DbgTrigSigSlct=1

# Exposure setup
arrayID=STIS_2Kx2K
arrayType=STIS
mosaicRows=1
mosaicCols=1
# preScan=24     # 24 prescan in x 
xPostScan=64    # 64 postscan in x
yPostScan=88    # 88 post scan in y
numOutputs=4    # 4 output channels
outputCfg=0     # N.A. when numOutputs is 4 
pxlRows=2048
pxlCols=2048
xStart[0]=1
yStart[0]=1
finDataType=32   # DHS_UINT four bytes 32 bits
frmsPerRdOut=1   # number of readout for one simple exposure
captureMode=1    # capture mode 0=NORMAL, 1=SEP, 2=BLOCKREAD
expMode=0        # mode of the exposure
processMode=0    # Processing mode -- Switch off the telemetry collection
expVector=1      # 1 = Normal Clr,Int,Read readout, 2=Clear only, 4=Read only
asyncVector=0    # Currently not used.
labSystem=2      # Do not collect telemetry for lab use
rawPxlSize=4     # number of Bytes in a raw pixel value
finPxlSize=4     # number of Bytes in a finished pixel value
avNameSIze=32    # Max character length of attribute name
avValueSize=32   # Max character length of attribute value
avCommentSize=64 # Max character length of attribute comment

## Exposure Attribute setup
filename=TOM     # To satisfy bug in generic library (?)
imageFile=TOM    # Default file name prefix
imageDir=/src
expID=1000
mcbIntTime=0     # Default to 0 seconds
intTime=0        # Still have to find out why the mcbIntTime attribute does not load the intTime attribute :-)

## Sequencer attributes
shutterDelay=2
xPreScan=24
postScan=64
parOvrScan=88
serOvrScan=64
idleBin=2
seqRowBin=1
seqColBin=1
sciRows=1112
sciCols=1112

# Rows=1112  # 1024 image rows + 88 post per output
# Cols=1112  # 1024 image cols + 24 pre + 64 post per output
# RowBin=1
# ColBin=1
# CdsDly=20
SeqClkDivide=0
contRun=0

# Pix Services setup
SCDataDestination=1     # Send raw data to the FPDP port
StreamModeEnable=1      # Use stream data mode
AcqMode=0               # Do not use packed pixels
SCDataPrecision=3       # Send complete 18-bit data sets

bufBaseAddr[0]=0        # Buffer addresses for image memory - slices of 631688 words (1124 columns x 562 rows) each
bufBaseAddr[1]=0x9A388
bufBaseAddr[2]=0x134710
bufBaseAddr[3]=0x1CEA98

# Clear the statistics
ClearStatistics=1

# Initialize the AFE Dacs
afe2ClkHiVal[]=2048
afe2ClkLoVal[]=2048
afe1ClkHiVal[]=2048
afe1ClkLoVal[]=2048

afe2HVBiasVal[]=2048
afe2LVBiasVal[]=2048
afe1HVBiasVal[]=2048
afe1LVBiasVal[]=2048

afe2VidOffVal[]=3000

afe1VidOffVal[0]=2100   # Empirically derived to set all quadrants at approx. 6500 ADU.
afe1VidOffVal[1]=2096
afe1VidOffVal[2]=2105
afe1VidOffVal[3]=2092


## NOTES ##
## The QL/SCDataSel is provides a means of supplying different precision data from an 18-bit ADC value:
## QL/SCDataSel Value            Result
##            00                               16-bit result form the least significant 16-bits of the ADC data i.e. ADC bits (15:0)
##            01                               16-bit result from ADC data bits (16:1)
##            10                               16-bit result from ADC data bits (17:2)
##            11                               Supplies full 18-bit precision in the lower 18-bits of a 32-bit pixel data word. 
##                                             Note that this mode is incompatible with packed data mode i.e. AcqMode = true. 
##                                             If acqMode_i is set true and QL/SCDataSel = "11' then the data precision result
##                                             is the same as setting the QL/SCDataSel to a value of "00".
##
## Data Destination codes:
## QL/SCDataDestSel Bits     Destination (Taken from assignments in the LCB_Control module).
##             Bit-0                           Serial FPDP port
##             Bit-1                           DHE SYNC Port
##             Bit-2                           UART Port
##             Bit-3                           GIGe Port
##
